@@ -199,7 +199,7 @@ class Parent(CFNExport):
             value = None
             if isinstance(obj, (str, zope.schema.TextLine, zope.schema.Text)):
                 value = getattr(self, name)
-            if isinstance(obj, (int, float, zope.schema.Int, zope.schema.Float)):
+            if isinstance(obj, (int, float, zope.schema.Int, zope.schema.Float, bool, zope.schema.Bool)):
                 value = getattr(self, name)
                 value = str(value)
 
